cmd/buzzkill: rename to rmplaysnippet

Our latest practice is to avoid creative names, but prefer descriptive and
boring ones. This is helpful for:

• discovering the command when looking at the list of commands available
• finding the command again (no need to remember the fun name)
• not polluting autocompletion in terminal (since GOPATH/bin is often in
  one's PATH)

New usage:

	$ rmplaysnippet
	usage: rmplaysnippet {https://play.golang.org/p/<id> | <id>}

Change-Id: Id3d9513a7229624607408facb62f76e206a93002
Reviewed-on: https://go-review.googlesource.com/c/148885
Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org>
Reviewed-by: Russ Cox <rsc@golang.org>
diff --git a/cmd/buzzkill/main.go b/cmd/rmplaysnippet/main.go
similarity index 88%
rename from cmd/buzzkill/main.go
rename to cmd/rmplaysnippet/main.go
index 7c7217f..ae21f58 100644
--- a/cmd/buzzkill/main.go
+++ b/cmd/rmplaysnippet/main.go
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
 // The buzzkill binary removes a code snippet from play.golang.org given its URL
 // or ID.
 package main
 
@@ -50,7 +50,7 @@
 	k := datastore.NameKey("Snippet", snippetID, nil)
 	if err := client.Delete(ctx, k); err != nil {
 		fmt.Fprintf(os.Stderr, "Unable to delete Snippet with ID %q: %v\n", snippetID, err)
-		fmt.Fprintf(os.Stderr, "buzzkill requires Application Default Credentials.\n")
+		fmt.Fprintf(os.Stderr, "rmplaysnippet requires Application Default Credentials.\n")
 		fmt.Fprintf(os.Stderr, "Did you run `gcloud auth application-default login`?\n")
 		os.Exit(1)
 	}
@@ -2,7 +2,7 @@
 // license that can be found in the LICENSE file.
 
-// The buzzkill binary removes a code snippet from play.golang.org given its URL
+// The rmplaysnippet binary removes a code snippet from play.golang.org given its URL
 // or ID.
 package main